@@ -27,7 +27,7 @@ class PyFormat(BatchTask):
             subprocess.run(args + names)
         except FileNotFoundError:
             print(
-                "Error: autoflake not found in PATH. Is it installed?", file=sys.stderr
+                "error: autoflake not found in PATH. Is it installed?", file=sys.stderr
             )
             return False
 
@@ -35,14 +35,14 @@ class PyFormat(BatchTask):
             args = [sys.executable, "-m", "black", "-q"]
             subprocess.run(args + names)
         except FileNotFoundError:
-            print("Error: black not found in PATH. Is it installed?", file=sys.stderr)
+            print("error: black not found in PATH. Is it installed?", file=sys.stderr)
             return False
 
         try:
             args = [sys.executable, "-m", "isort", "--profile", "black", "-q"]
             subprocess.run(args + names)
         except FileNotFoundError:
-            print("Error: isort not found in PATH. Is it installed?", file=sys.stderr)
+            print("error: isort not found in PATH. Is it installed?", file=sys.stderr)
             return False
 
         return True
